@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.5.0';
+our $VERSION = '1.0.6.0';
 
 use Exporter 'import';
 
@@ -37,7 +37,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-# Items to export into callers namespace by default. Note: do not export
+# Items to export into caller's namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
@@ -55,7 +55,10 @@ our %EXPORT_TAGS = (
                                   OP_NEAR
                                   OP_PHRASE
 				  OP_VALUE_RANGE
+				  OP_SCALE_WEIGHT
                                   OP_ELITE_SET
+				  OP_VALUE_GE
+				  OP_VALUE_LE
                                  ) ],
                     'db' => [ qw(
                                  DB_OPEN
@@ -287,6 +290,14 @@ final word as a wildcarded match, unless it is followed by
 whitespace, to produce more stable results from interactive
 searches.
 
+=item FLAG_SPELLING_CORRECTION
+
+=item FLAG_SYNONYM
+
+=item FLAG_AUTO_SYNONYMS
+
+=item FLAG_AUTO_MULTIWORD_SYNONYMS
+
 =back
 
 =head1 :qpstem
@@ -303,8 +314,8 @@ Don't stem any terms.
 
 =item STEM_SOME
 
-Stem some terms, in a manner compatible with Omega (capitalised words aren't
-stemmed, and get an 'R' prefix).
+Stem some terms, in a manner compatible with Omega (capitalised words and those
+in phrases aren't stemmed).
 
 =back
 
@@ -390,6 +401,7 @@ L<Search::Xapian::BoolWeight>,
 L<Search::Xapian::Database>,
 L<Search::Xapian::Document>,
 L<Search::Xapian::Enquire>,
+L<Search::Xapian::MultiValueSorter>,
 L<Search::Xapian::PositionIterator>,
 L<Search::Xapian::PostingIterator>,
 L<Search::Xapian::QueryParser>,
